HP X9320 Guide de l'utilisateur Page 68

  • Télécharger
  • Ajouter à mon manuel
  • Imprimer
  • Page
    / 150
  • Table des matières
  • MARQUE LIVRES
  • Noté. / 5. Basé sur avis des utilisateurs
Vue de la page 67
ibrix_health
Checks the functional health of file serving nodes and X9000 clients.
Description
ibrix_health runs a set of health checks on all hosts or the specified hosts and reports the
results. To constrain the report to show only hosts that failed, include the -f option.
On both file serving nodes and X9000 clients, the check determines whether information maps on
the tested hosts are consistent with the configuration database.
Checks run on file serving nodes do the following:
Ping remote file serving nodes that share a network with the test hosts but only if the test hosts
do not have an open connection to the remote servers. Remote servers that can be pinged
may not be connected to a test host because of a Linux or X9000 Software problem. Remote
servers that cannot be pinged may be down or have a network problem.
If test hosts are assigned to be network interface monitors, ping their monitored interfaces to
assess the health of the connection.
Determine whether hosts can read their physical volumes.
Health checks are reported as Passed, Failed, or Warning:
Passed: All tested hosts and standbys passed every health check.
Failed: One or more tested hosts failed a health check. The health status of standbys for file
serving nodes is not included when this result is calculated.
Warning: A suboptimal condition that may require attention was found on one or more tested
hosts or standbys.
The terms have the same meaning for individual file serving nodes and X9000 clients. A standby
for a file serving node is not considered when the result is determined for the node.
The basic (-l) report includes the following for each host: hostname, test result (passed/failed),
host type (server/client), state (up/down), and date of last update.
The detailed report consists of a summary report plus the following data: a summary of the test
results; host information such as operational state, performance data, and version data; non-default
host tunings; and the results of the health checks. By default, the “Result Information” field in a
detailed report provides data only for health checks that received a Failed or a Warned result.
You can expand a detailed report to also provide data about checks that received a Passed result,
as well as details about the file system and segments.
Synopsis
Perform health checks and provide a summary report of the results:
ibrix_health -l [-h HOSTLIST] [-f] [-u] [-b] [-t SCRIPTNAMELIST]
The command is run on the specified file serving nodes and X9000 clients. The options are:
-h HOSTLIST: Runs health checks on the specified file serving nodes and X9000 clients.
-f: Reports only hosts that failed a test.
-u: Reports only hosts known to be up.
-b: Includes standbys for file serving nodes.
-t SCRIPTNAMELIST: Runs the specified scripts and include them in the health report.
Display a summary health report:
ibrix_health -i -h HOSTLIST [-f] [-b] [-s] [-v] [-t SCRIPTNAMELIST]
The options are:
h HOSTLIST: Runs health checks on the specified file serving nodes and X9000 clients.
68 X9000 File Serving Software commands
Vue de la page 67
1 2 ... 63 64 65 66 67 68 69 70 71 72 73 ... 149 150

Commentaires sur ces manuels

Pas de commentaire

Tripp Lite SU6000RT3UHVXL podręczniki

Instrukcje obsługi i podręczniki użytkownika dla Zasilacze bezprzerwowe (UPS) Tripp Lite SU6000RT3UHVXL.
Dostarczamy 1 pdf podręczników Tripp Lite SU6000RT3UHVXL do pobrania za darmo według typów dokumentów: Arkusz Danych






Więcej produktów i instrukcji dla Zasilacze bezprzerwowe (UPS) Tripp Lite

Modele Rodzaj dokumentu
SU3000RTXLCD3U Arkusz Danych   Tripp Lite SmartOnline 100-127V 3kVA 2.7kW On-Line Double-Conversion UPS, Extended Run, SNMP, Webcard, 3U Rack, LCD display, USB, DB9 Serial, 6 strony
SU1000XLCD Arkusz Danych   Tripp Lite SmartOnline 100-127V 1kVA 900W On-Line Double-Conversion UPS, Extended Run, SNMP, Webcard, Tower, LCD display, USB, DB9 Serial, 6 strony
SU2200XLCD Arkusz Danych   Tripp Lite SmartOnline 100-127V 2.2kVA 1.8kW On-Line Double-Conversion UPS, Extended Run, SNMP, Webcard, Tower, LCD display, USB, DB9 Serial, 7 strony
SU2200RTXLCD2U Arkusz Danych   Tripp Lite SmartOnline 100-127V 2.2kVA 1.8kW On-Line Double-Conversion UPS, Extended Run, SNMP, Webcard, 2U Rack/Tower, LCD display, USB, DB9 Serial, 7 strony
SU1000RTXLCD2U Arkusz Danych   Tripp Lite SmartOnline 100-127V 1kVA 900W On-Line Double-Conversion UPS, Extended Run, SNMP, Webcard, 2U Rack/Tower, LCD display, USB, DB9 Serial, 6 strony
SU10KRT3/1X Arkusz Danych   Tripp Lite SmartOnline 3-Phase In/1-Phase Out 200-240V 10kVA 7kW On-Line, Double-Conversion UPS, Extended Run, SNMP, Webcard pre-installed, 6U Rack/Tower, USB, DB9 Serial, 5 strony
SMART2200RMXL2UP Arkusz Danych   Tripp Lite 2200 VA UPS, 6 strony
SM5000RT3UTAA Arkusz Danych   Tripp Lite SM5000RT3UTAA uninterruptible power supply (UPS), 6 strony
SMART1050SLTAA Arkusz Danych   Tripp Lite SMART1050SLTAA uninterruptible power supply (UPS), 6 strony
SMX3000RT2UTAA Arkusz Danych   Tripp Lite SMX3000RT2UTAA uninterruptible power supply (UPS), 6 strony
SU1500RTXLCD2U Arkusz Danych   Tripp Lite SmartOnline 100-127V 1.5kVA 1.35kW On-Line Double-Conversion UPS, Extended Run, SNMP, Webcard, 2U Rack/Tower, LCD display, USB, DB9 Serial, 7 strony
HT-RL15UPS Arkusz Danych   Tripp Lite HTRL15UPS, 5 strony
SU16KRTHW Arkusz Danych   Tripp Lite SmartOnline 200-240V, 16kVA 14.4kW On-Line Double-Conversion UPS, N+1, Extended Run, SNMP, Webcard, 12U Rack/Tower, USB, DB9 Serial, Hardwire, 6 strony
SU5000RT4UTF Arkusz Danych   Tripp Lite SmartOnline 208/120V 5kVA 4.5kW On-Line Double-Conversion UPS, Extended Run, SNMP, Webcard, 6U Rack/Tower, USB, DB9 Serial, 6 strony
SU12000RT4UHW Arkusz Danych   Tripp Lite SmartOnline 240/120V or 208/120V 12kVA 8.4kW On-Line Double-Conversion UPS, Extended Run, SNMP, Webcard, 8U, USB, DB9 Serial, Hardwire, 6 strony
SU20KX Arkusz Danych   Tripp Lite SmartOnline 20kVA 16kW Modular 3-Phase UPS System, On-line Double-Conversion UPS, SNMP, Webcard, DB9 Serial, 5 strony
SU6000RT4UTF Arkusz Danych   Tripp Lite SmartOnline 240/208/120V 6kVA 5.4kW On-Line Double-Conversion UPS, Low-Voltage Transformer, Extended Run, SNMP, Webcard, 6U Rack/Tower, Bypass Switch, 7 strony
SU6000RT4UHVHW Arkusz Danych   Tripp Lite SmartOnline 200-240V 6kVA 5.4kW On-Line Double-Conversion UPS, Extended run, SNMP, Webcard, 4U Rack/Tower, USB, DB9 Serial, Hardwire, 6 strony
SU3000RTXR3UHW Arkusz Danych   Tripp Lite SmartOnline 110-120V 3kVA 2.4kW On-Line Double-Conversion UPS, Extended Run, SNMP, Webcard, 3U Rack/Tower, USB, DB9 Serial, Hardwire, 6 strony
SU40K Arkusz Danych   Tripp Lite SU40K uninterruptible power supply (UPS), 6 strony